@@ -36,6 +36,10 @@ type ContainerStartOptions struct {
 	Checkpoint string
 	// CheckpointDir is the directory to store checkpoints
 	CheckpointDir string
+	// NerdctlCmd is the command name of nerdctl
+	NerdctlCmd string
+	// NerdctlArgs is the arguments of nerdctl
+	NerdctlArgs []string
 }
 
 // ContainerKillOptions specifies options for `nerdctl (container) kill`.
@@ -329,6 +333,10 @@ type ContainerRestartOptions struct {
 	Timeout *time.Duration
 	// Signal to send to stop the container, before sending SIGKILL
 	Signal string
+	// NerdctlCmd is the command name of nerdctl
+	NerdctlCmd string
+	// NerdctlArgs is the arguments of nerdctl
+	NerdctlArgs []string
 }
 
 // ContainerPauseOptions specifies options for `nerdctl (container) pause`.
@@ -346,7 +354,14 @@ type ContainerPruneOptions struct {
 }
 
 // ContainerUnpauseOptions specifies options for `nerdctl (container) unpause`.
-type ContainerUnpauseOptions ContainerPauseOptions
+type ContainerUnpauseOptions struct {
+	Stdout   io.Writer
+	GOptions GlobalCommandOptions
+	// NerdctlCmd is the command name of nerdctl
+	NerdctlCmd string
+	// NerdctlArgs is the arguments of nerdctl
+	NerdctlArgs []string
+}
 
 // ContainerRemoveOptions specifies options for `nerdctl (container) rm`.
 type ContainerRemoveOptions struct {
