@@ -21,25 +21,32 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"io/fs"
 	"os"
 	"path/filepath"
 	"reflect"
 	"runtime"
 	"strings"
 
-	"github.com/containerd/containerd"
-	"github.com/containerd/containerd/containers"
-	"github.com/containerd/containerd/oci"
-	"github.com/containerd/nerdctl/pkg/api/types"
-	"github.com/containerd/nerdctl/pkg/clientutil"
-	"github.com/containerd/nerdctl/pkg/dnsutil/hostsstore"
-	"github.com/containerd/nerdctl/pkg/idutil/containerwalker"
-	"github.com/containerd/nerdctl/pkg/labels"
-	"github.com/containerd/nerdctl/pkg/mountutil"
-	"github.com/containerd/nerdctl/pkg/netutil"
-	"github.com/containerd/nerdctl/pkg/netutil/nettype"
-	"github.com/containerd/nerdctl/pkg/strutil"
 	"github.com/opencontainers/runtime-spec/specs-go"
+
+	containerd "github.com/containerd/containerd/v2/client"
+	"github.com/containerd/containerd/v2/core/containers"
+	"github.com/containerd/containerd/v2/pkg/oci"
+	"github.com/containerd/log"
+
+	"github.com/containerd/nerdctl/v2/pkg/api/types"
+	"github.com/containerd/nerdctl/v2/pkg/clientutil"
+	"github.com/containerd/nerdctl/v2/pkg/dnsutil/hostsstore"
+	"github.com/containerd/nerdctl/v2/pkg/idutil/containerwalker"
+	"github.com/containerd/nerdctl/v2/pkg/internal/filesystem"
+	"github.com/containerd/nerdctl/v2/pkg/labels"
+	"github.com/containerd/nerdctl/v2/pkg/mountutil"
+	"github.com/containerd/nerdctl/v2/pkg/netutil"
+	"github.com/containerd/nerdctl/v2/pkg/netutil/nettype"
+	"github.com/containerd/nerdctl/v2/pkg/resolvconf"
+	"github.com/containerd/nerdctl/v2/pkg/rootlessutil"
+	"github.com/containerd/nerdctl/v2/pkg/strutil"
 )
 
 const (
@@ -82,6 +89,36 @@ func withCustomHosts(src string) func(context.Context, oci.Client, *containers.C
 	}
 }
 
+func fetchDNSResolverConfig(netOpts types.NetworkOptions) ([]string, []string, []string, error) {
+	dns := netOpts.DNSServers
+	dnsSearch := netOpts.DNSSearchDomains
+	dnsOptions := netOpts.DNSResolvConfOptions
+
+	conf, err := resolvconf.Get()
+	if err != nil {
+		if !errors.Is(err, fs.ErrNotExist) {
+			return nil, nil, nil, err
+		}
+		// if resolvConf file does't exist, using default resolvers
+		conf = &resolvconf.File{}
+		log.L.WithError(err).Debugf("resolvConf file doesn't exist on host")
+	}
+	conf, err = resolvconf.FilterResolvDNS(conf.Content, true)
+	if err != nil {
+		return nil, nil, nil, err
+	}
+	if len(netOpts.DNSServers) == 0 {
+		dns = resolvconf.GetNameservers(conf.Content, resolvconf.IP)
+	}
+	if len(netOpts.DNSSearchDomains) == 0 {
+		dnsSearch = resolvconf.GetSearchDomains(conf.Content)
+	}
+	if len(netOpts.DNSResolvConfOptions) == 0 {
+		dnsOptions = resolvconf.GetOptions(conf.Content)
+	}
+	return dns, dnsSearch, dnsOptions, err
+}
+
 // NetworkOptionsManager types.NetworkOptionsManager is an interface for reading/setting networking
 // options for containers based on the provided command flags.
 type NetworkOptionsManager interface {
@@ -128,6 +165,10 @@ func NewNetworkingOptionsManager(globalOptions types.GlobalCommandOptions, netOp
 		manager = &containerNetworkManager{globalOptions, netOpts, client}
 	case nettype.CNI:
 		manager = &cniNetworkManager{globalOptions, netOpts, client, cniNetworkManagerPlatform{}}
+	case nettype.Namespace:
+		// We'll handle Namespace networking identically to Host-mode networking, but
+		// put the container in the specified network namespace instead of the root.
+		manager = &hostNetworkManager{globalOptions, netOpts, client}
 	default:
 		return nil, fmt.Errorf("unexpected container networking type: %q", netType)
 	}
@@ -149,31 +190,157 @@ func (m *noneNetworkManager) NetworkOptions() types.NetworkOptions {
 
 // VerifyNetworkOptions Verifies that the internal network settings are correct.
 func (m *noneNetworkManager) VerifyNetworkOptions(_ context.Context) error {
-	// No options to verify if no network settings are provided.
+	err := validateUtsSettings(m.netOpts)
+	if err != nil {
+		return err
+	}
+
 	return nil
 }
 
 // SetupNetworking Performs setup actions required for the container with the given ID.
-func (m *noneNetworkManager) SetupNetworking(_ context.Context, _ string) error {
-	return nil
+func (m *noneNetworkManager) SetupNetworking(ctx context.Context, containerID string) error {
+	// Retrieve the container
+	container, err := m.client.ContainerService().Get(ctx, containerID)
+	if err != nil {
+		return err
+	}
+
+	// Get the dataStore
+	dataStore, err := clientutil.DataStore(m.globalOptions.DataRoot, m.globalOptions.Address)
+	if err != nil {
+		return err
+	}
+
+	// Get the hostsStore
+	hs, err := hostsstore.New(dataStore, container.Labels[labels.Namespace])
+	if err != nil {
+		return err
+	}
+
+	// Get extra-hosts
+	extraHostsJSON := container.Labels[labels.ExtraHosts]
+	var extraHosts []string
+	if err = json.Unmarshal([]byte(extraHostsJSON), &extraHosts); err != nil {
+		return err
+	}
+
+	hosts := make(map[string]string)
+	for _, host := range extraHosts {
+		if v := strings.SplitN(host, ":", 2); len(v) == 2 {
+			hosts[v[0]] = v[1]
+		}
+	}
+
+	// Prep the meta
+	hsMeta := hostsstore.Meta{
+		ID:         container.ID,
+		Hostname:   container.Labels[labels.Hostname],
+		ExtraHosts: hosts,
+		Name:       container.Labels[labels.Name],
+	}
+
+	// Save the meta information
+	return hs.Acquire(hsMeta)
 }
 
 // CleanupNetworking Performs any required cleanup actions for the given container.
 // Should only be called to revert any setup steps performed in SetupNetworking.
-func (m *noneNetworkManager) CleanupNetworking(_ context.Context, _ containerd.Container) error {
-	return nil
+func (m *noneNetworkManager) CleanupNetworking(ctx context.Context, container containerd.Container) error {
+	// Get the dataStore
+	dataStore, err := clientutil.DataStore(m.globalOptions.DataRoot, m.globalOptions.Address)
+	if err != nil {
+		return err
+	}
+
+	// Get labels
+	lbls, err := container.Labels(ctx)
+	if err != nil {
+		return err
+	}
+
+	// Get the hostsStore
+	hs, err := hostsstore.New(dataStore, lbls[labels.Namespace])
+	if err != nil {
+		return err
+	}
+
+	// Release
+	return hs.Release(container.ID())
 }
 
 // InternalNetworkingOptionLabels Returns the set of NetworkingOptions which should be set as labels on the container.
 func (m *noneNetworkManager) InternalNetworkingOptionLabels(_ context.Context) (types.NetworkOptions, error) {
-	return m.netOpts, nil
+	opts := m.netOpts
+	// Cannot have a MAC address in host networking mode.
+	opts.MACAddress = ""
+	return opts, nil
 }
 
 // ContainerNetworkingOpts Returns a slice of `oci.SpecOpts` and `containerd.NewContainerOpts` which represent
 // the network specs which need to be applied to the container with the given ID.
-func (m *noneNetworkManager) ContainerNetworkingOpts(_ context.Context, _ string) ([]oci.SpecOpts, []containerd.NewContainerOpts, error) {
-	// No options to return if no network settings are provided.
-	return []oci.SpecOpts{}, []containerd.NewContainerOpts{}, nil
+func (m *noneNetworkManager) ContainerNetworkingOpts(_ context.Context, containerID string) ([]oci.SpecOpts, []containerd.NewContainerOpts, error) {
+	dataStore, err := clientutil.DataStore(m.globalOptions.DataRoot, m.globalOptions.Address)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	stateDir, err := ContainerStateDirPath(m.globalOptions.Namespace, dataStore, containerID)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	resolvConfPath := filepath.Join(stateDir, "resolv.conf")
+	dns, dnsSearch, dnsOptions, err := fetchDNSResolverConfig(m.netOpts)
+	if err != nil {
+		return nil, nil, err
+	}
+	_, err = resolvconf.Build(resolvConfPath, dns, dnsSearch, dnsOptions)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	hs, err := hostsstore.New(dataStore, m.globalOptions.Namespace)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	etcHostsPath, err := hs.AllocHostsFile(containerID, []byte{})
+	if err != nil {
+		return nil, nil, err
+	}
+
+	// `/etc/host` does not exist in FreeBSD minimal rootfs image
+	// `/etc/resolv.conf` does not exist in FreeBSD minimal rootfs image
+	specs := []oci.SpecOpts{}
+	if runtime.GOOS == "linux" {
+		specs = []oci.SpecOpts{
+			withDedupMounts("/etc/resolv.conf", withCustomResolvConf(resolvConfPath)),
+			withDedupMounts("/etc/hosts", withCustomHosts(etcHostsPath)),
+		}
+	}
+
+	// `/etc/hostname` does not exist on FreeBSD
+	if runtime.GOOS == "linux" {
+		// If no hostname is set, default to first 12 characters of the container ID.
+		hostname := m.netOpts.Hostname
+		if hostname == "" {
+			hostname = containerID
+			if len(hostname) > 12 {
+				hostname = hostname[0:12]
+			}
+		}
+		m.netOpts.Hostname = hostname
+
+		hostnameOpts, err := writeEtcHostnameForContainer(m.globalOptions, m.netOpts.Hostname, containerID)
+		if err != nil {
+			return nil, nil, err
+		}
+		if hostnameOpts != nil {
+			specs = append(specs, hostnameOpts...)
+		}
+	}
+	return specs, []containerd.NewContainerOpts{}, nil
 }
 
 // types.NetworkOptionsManager implementation for container networking settings.
@@ -195,13 +362,15 @@ func (m *containerNetworkManager) VerifyNetworkOptions(_ context.Context) error
 		return errors.New("container networking mode is currently only supported on Linux")
 	}
 
-	if m.netOpts.NetworkSlice != nil && len(m.netOpts.NetworkSlice) > 1 {
-		return errors.New("conflicting options: only one network specification is allowed when using '--network=container:<container>'")
+	err := validateUtsSettings(m.netOpts)
+	if err != nil {
+		return err
 	}
 
+	// Note that mac-address is accepted, though it is a no-op
 	nonZeroParams := nonZeroMapValues(map[string]interface{}{
-		"--hostname":    m.netOpts.Hostname,
-		"--mac-address": m.netOpts.MACAddress,
+		"--hostname":   m.netOpts.Hostname,
+		"--domainname": m.netOpts.Domainname,
 		// NOTE: an empty slice still counts as a non-zero value so we check its length:
 		"-p/--publish": len(m.netOpts.PortMappings) != 0,
 		"--dns":        len(m.netOpts.DNSServers) != 0,
@@ -226,10 +395,18 @@ func (m *containerNetworkManager) getContainerNetworkFilePaths(containerID strin
 	if err != nil {
 		return "", "", "", err
 	}
+	hostsStore, err := hostsstore.New(dataStore, m.globalOptions.Namespace)
+	if err != nil {
+		return "", "", "", err
+	}
 
 	hostnamePath := filepath.Join(conStateDir, "hostname")
 	resolvConfPath := filepath.Join(conStateDir, "resolv.conf")
-	etcHostsPath := hostsstore.HostsPath(dataStore, m.globalOptions.Namespace, containerID)
+
+	etcHostsPath, err := hostsStore.HostsPath(containerID)
+	if err != nil {
+		return "", "", "", err
+	}
 
 	return hostnamePath, resolvConfPath, etcHostsPath, nil
 }
@@ -285,6 +462,8 @@ func (m *containerNetworkManager) InternalNetworkingOptionLabels(ctx context.Con
 	if m.netOpts.NetworkSlice == nil || len(m.netOpts.NetworkSlice) != 1 {
 		return opts, fmt.Errorf("conflicting options: exactly one network specification is allowed when using '--network=container:<container>'")
 	}
+	// MacAddress is not allowed with container networking
+	opts.MACAddress = ""
 
 	container, err := m.getNetworkingContainerForArgument(ctx, m.netOpts.NetworkSlice[0], m.client)
 	if err != nil {
@@ -312,6 +491,10 @@ func (m *containerNetworkManager) ContainerNetworkingOpts(ctx context.Context, _
 		return nil, nil, err
 	}
 	hostname := s.Hostname
+	// if Utsnamespace is set we should not set the hostname
+	if m.netOpts.UTSNamespace == UtsNamespaceHost {
+		hostname = ""
+	}
 
 	netNSPath, err := ContainerNetNSPath(ctx, container)
 	if err != nil {
@@ -356,24 +539,78 @@ func (m *hostNetworkManager) VerifyNetworkOptions(_ context.Context) error {
 		return errors.New("cannot use host networking on Windows")
 	}
 
-	if m.netOpts.MACAddress != "" {
-		return errors.New("conflicting options: mac-address and the network mode")
-	}
-
 	return validateUtsSettings(m.netOpts)
 }
 
 // SetupNetworking Performs setup actions required for the container with the given ID.
-func (m *hostNetworkManager) SetupNetworking(_ context.Context, _ string) error {
-	// NOTE: there are no setup steps required for host networking.
-	return nil
+func (m *hostNetworkManager) SetupNetworking(ctx context.Context, containerID string) error {
+	// Retrieve the container
+	container, err := m.client.ContainerService().Get(ctx, containerID)
+	if err != nil {
+		return err
+	}
+
+	// Get the dataStore
+	dataStore, err := clientutil.DataStore(m.globalOptions.DataRoot, m.globalOptions.Address)
+	if err != nil {
+		return err
+	}
+
+	// Get the hostsStore
+	hs, err := hostsstore.New(dataStore, container.Labels[labels.Namespace])
+	if err != nil {
+		return err
+	}
+
+	// Get extra-hosts
+	extraHostsJSON := container.Labels[labels.ExtraHosts]
+	var extraHosts []string
+	if err = json.Unmarshal([]byte(extraHostsJSON), &extraHosts); err != nil {
+		return err
+	}
+
+	hosts := make(map[string]string)
+	for _, host := range extraHosts {
+		if v := strings.SplitN(host, ":", 2); len(v) == 2 {
+			hosts[v[0]] = v[1]
+		}
+	}
+
+	// Prep the meta
+	hsMeta := hostsstore.Meta{
+		ID:         container.ID,
+		Hostname:   container.Labels[labels.Hostname],
+		ExtraHosts: hosts,
+		Name:       container.Labels[labels.Name],
+	}
+
+	// Save the meta information
+	return hs.Acquire(hsMeta)
 }
 
 // CleanupNetworking Performs any required cleanup actions for the given container.
 // Should only be called to revert any setup steps performed in SetupNetworking.
-func (m *hostNetworkManager) CleanupNetworking(_ context.Context, _ containerd.Container) error {
-	// NOTE: there are no setup steps required for host networking.
-	return nil
+func (m *hostNetworkManager) CleanupNetworking(ctx context.Context, container containerd.Container) error {
+	// Get the dataStore
+	dataStore, err := clientutil.DataStore(m.globalOptions.DataRoot, m.globalOptions.Address)
+	if err != nil {
+		return err
+	}
+
+	// Get labels
+	lbls, err := container.Labels(ctx)
+	if err != nil {
+		return err
+	}
+
+	// Get the hostsStore
+	hs, err := hostsstore.New(dataStore, lbls[labels.Namespace])
+	if err != nil {
+		return err
+	}
+
+	// Release
+	return hs.Release(container.ID())
 }
 
 // InternalNetworkingOptionLabels Returns the set of NetworkingOptions which should be set as labels on the container.
@@ -397,16 +634,24 @@ func withDedupMounts(mountPath string, defaultSpec oci.SpecOpts) oci.SpecOpts {
 	}
 }
 
-func copyFileContent(src string, dst string) error {
-	data, err := os.ReadFile(src)
-	if err != nil {
-		return err
+// getHostNetworkingNamespace Returns an oci.SpecOpts representing the network namespace to
+// be used by the hostNetworkManager. When running with `--network=host` this would be the host's
+// root namespace, but `--network=ns:<path>` can be used to run a container in an existing netns.
+func getHostNetworkingNamespace(netModeArg string) (oci.SpecOpts, error) {
+	if !strings.Contains(netModeArg, ":") {
+		// Use the host root namespace by default
+		return oci.WithHostNamespace(specs.NetworkNamespace), nil
 	}
-	err = os.WriteFile(dst, data, 0644)
-	if err != nil {
-		return err
+
+	netItems := strings.Split(netModeArg, ":")
+	if len(netItems) < 2 {
+		return nil, fmt.Errorf("namespace networking argument format must be 'ns:<path>', got: %q", netModeArg)
 	}
-	return nil
+	netnsPath := netItems[1]
+	return oci.WithLinuxNamespace(specs.LinuxNamespace{
+		Type: specs.NetworkNamespace,
+		Path: netnsPath,
+	}), nil
 }
 
 // ContainerNetworkingOpts Returns a slice of `oci.SpecOpts` and `containerd.NewContainerOpts` which represent
@@ -426,28 +671,55 @@ func (m *hostNetworkManager) ContainerNetworkingOpts(_ context.Context, containe
 	}
 
 	resolvConfPath := filepath.Join(stateDir, "resolv.conf")
-	copyFileContent("/etc/resolv.conf", resolvConfPath)
-
-	etcHostsPath, err := hostsstore.AllocHostsFile(dataStore, m.globalOptions.Namespace, containerID)
+	dns, dnsSearch, dnsOptions, err := fetchDNSResolverConfig(m.netOpts)
 	if err != nil {
 		return nil, nil, err
 	}
-	copyFileContent("/etc/hosts", etcHostsPath)
 
+	_, err = resolvconf.Build(resolvConfPath, dns, dnsSearch, dnsOptions)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	hs, err := hostsstore.New(dataStore, m.globalOptions.Namespace)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	content, err := filesystem.ReadFile("/etc/hosts")
+	if err != nil {
+		return nil, nil, err
+	}
+
+	etcHostsPath, err := hs.AllocHostsFile(containerID, content)
+	if err != nil {
+		return nil, nil, err
+	}
+
+	netModeArg := m.netOpts.NetworkSlice[0]
+	netNamespace, err := getHostNetworkingNamespace(netModeArg)
+	if err != nil {
+		return nil, nil, err
+	}
 	specs := []oci.SpecOpts{
-		oci.WithHostNamespace(specs.NetworkNamespace),
-		withDedupMounts("/etc/hosts", withCustomHosts(etcHostsPath)),
+		netNamespace,
 		withDedupMounts("/etc/resolv.conf", withCustomResolvConf(resolvConfPath)),
+		withDedupMounts("/etc/hosts", withCustomHosts(etcHostsPath)),
 	}
 
 	// `/etc/hostname` does not exist on FreeBSD
-	if runtime.GOOS == "linux" && m.netOpts.UTSNamespace != UtsNamespaceHost {
-		// If no hostname is set, default to first 12 characters of the container ID.
+	if runtime.GOOS == "linux" {
 		hostname := m.netOpts.Hostname
 		if hostname == "" {
-			hostname = containerID
-			if len(hostname) > 12 {
-				hostname = hostname[0:12]
+			// Hostname by default should be the host hostname
+			hostname, err = os.Hostname()
+			if err != nil {
+				log.L.WithError(err).Warn("could not get hostname")
+				// If no hostname is set, default to first 12 characters of the container ID.
+				hostname = containerID
+				if len(hostname) > 12 {
+					hostname = hostname[0:12]
+				}
 			}
 		}
 		m.netOpts.Hostname = hostname
@@ -459,11 +731,54 @@ func (m *hostNetworkManager) ContainerNetworkingOpts(_ context.Context, containe
 		if hostnameOpts != nil {
 			specs = append(specs, hostnameOpts...)
 		}
+		if m.netOpts.Domainname != "" {
+			specs = append(specs, oci.WithDomainname(m.netOpts.Domainname))
+		}
+	}
+
+	if rootlessutil.IsRootless() {
+		detachedNetNS, err := rootlessutil.DetachedNetNS()
+		if err != nil {
+			return nil, nil, fmt.Errorf("failed to check whether RootlessKit is running with --detach-netns: %w", err)
+		}
+		if detachedNetNS != "" {
+			// For rootless + host netns, we can't mount sysfs.
+			// We can't (non-recursively) bind mount /sys, either.
+			//
+			// TODO: consider to just rbind /sys from the host with rro,
+			// when rro is available (kernel >= 5.12, runc >= 1.1).
+			//
+			// Relevant: https://github.com/moby/buildkit/blob/v0.12.4/util/rootless/specconv/specconv_linux.go#L15-L34
+			specs = append(specs, withRemoveSysfs)
+		}
 	}
 
 	return specs, cOpts, nil
 }
 
+func withRemoveSysfs(_ context.Context, _ oci.Client, c *containers.Container, s *oci.Spec) error {
+	var hasSysfs bool
+	for _, mount := range s.Mounts {
+		if mount.Type == "sysfs" {
+			hasSysfs = true
+			break
+		}
+	}
+	if !hasSysfs {
+		// NOP, as the user has specified a custom /sys mount
+		return nil
+	}
+	var mounts []specs.Mount // nolint: prealloc
+	for _, mount := range s.Mounts {
+		if strings.HasPrefix(mount.Destination, "/sys") {
+			continue
+		}
+		mounts = append(mounts, mount)
+	}
+	s.Mounts = mounts
+	return nil
+}
+
 // types.NetworkOptionsManager implementation for CNI networking settings.
 // This is a more specialized and OS-dependendant networking model so this
 // struct provides different implementations on different platforms.
@@ -486,9 +801,9 @@ func validateUtsSettings(netOpts types.NetworkOptions) error {
 	}
 
 	// Docker considers this a validation error so keep compat.
-	// https://docs.docker.com/engine/reference/run/#uts-settings---uts
-	if utsNamespace == UtsNamespaceHost && netOpts.Hostname != "" {
-		return fmt.Errorf("conflicting options: cannot set a --hostname with --uts=host")
+	// https://docs.docker.com/reference/cli/docker/container/run/#uts
+	if utsNamespace == UtsNamespaceHost && (netOpts.Hostname != "" || netOpts.Domainname != "") {
+		return fmt.Errorf("conflicting options: cannot set --hostname and/or --domainname with --uts=host")
 	}
 
 	return nil
@@ -498,6 +813,7 @@ func validateUtsSettings(netOpts types.NetworkOptions) error {
 // Nerdctl-managed datastore and returns the oci.SpecOpts required in the container
 // spec for the file to be mounted under /etc/hostname in the new container.
 // If the hostname is empty, the leading 12 characters of the containerID
+// This sets world readable permissions on /etc/hostname, ignoring umask
 func writeEtcHostnameForContainer(globalOptions types.GlobalCommandOptions, hostname string, containerID string) ([]oci.SpecOpts, error) {
 	if containerID == "" {
 		return nil, fmt.Errorf("container ID is required for setting up hostname file")
@@ -514,7 +830,12 @@ func writeEtcHostnameForContainer(globalOptions types.GlobalCommandOptions, host
 	}
 
 	hostnamePath := filepath.Join(stateDir, "hostname")
-	if err := os.WriteFile(hostnamePath, []byte(hostname+"\n"), 0644); err != nil {
+	if err := filesystem.WriteFile(hostnamePath, []byte(hostname+"\n"), 0644); err != nil {
+		return nil, err
+	}
+
+	err = os.Chmod(hostnamePath, 0644)
+	if err != nil {
 		return nil, err
 	}
 
@@ -523,18 +844,16 @@ func writeEtcHostnameForContainer(globalOptions types.GlobalCommandOptions, host
 
 // Loads all available networks and verifies that every selected network
 // from the networkSlice is of a type within supportedTypes.
+// nolint:unused
 func verifyNetworkTypes(env *netutil.CNIEnv, networkSlice []string, supportedTypes []string) (map[string]*netutil.NetworkConfig, error) {
-	netMap, err := env.NetworkMap()
-	if err != nil {
-		return nil, err
-	}
-
 	res := make(map[string]*netutil.NetworkConfig, len(networkSlice))
+	var netConfig *netutil.NetworkConfig
+	var err error
 	for _, netstr := range networkSlice {
-		netConfig, ok := netMap[netstr]
-		if !ok {
-			return nil, fmt.Errorf("network %s not found", netstr)
+		if netConfig, err = env.NetworkByNameOrID(netstr); err != nil {
+			return nil, err
 		}
+
 		netType := netConfig.Plugins[0].Network.Type
 		if supportedTypes != nil && !strutil.InStringSlice(supportedTypes, netType) {
 			return nil, fmt.Errorf("network type %q is not supported for network mapping %q, must be one of: %v", netType, netstr, supportedTypes)
@@ -574,12 +893,6 @@ func NetworkOptionsFromSpec(spec *specs.Spec) (types.NetworkOptions, error) {
 	}
 	opts.NetworkSlice = networks
 
-	if portsJSON := spec.Annotations[labels.Ports]; portsJSON != "" {
-		if err := json.Unmarshal([]byte(portsJSON), &opts.PortMappings); err != nil {
-			return opts, err
-		}
-	}
-
 	return opts, nil
 }
 
