@@ -206,7 +206,7 @@ func GenerateSharingPIDOpts(ctx context.Context, targetCon containerd.Container)
 }
 
 // Start starts `container` with `attach` flag. If `attach` is true, it will attach to the container's stdio.
-func Start(ctx context.Context, container containerd.Container, isAttach bool, isInteractive bool, client *containerd.Client, detachKeys string, checkpointDir string, cfg *config.Config) (err error) {
+func Start(ctx context.Context, container containerd.Container, isAttach bool, isInteractive bool, client *containerd.Client, detachKeys string, checkpointDir string, cfg *config.Config, nerdctlCmd string, nerdctlArgs []string) (err error) {
 	// defer the storage of start error in the dedicated label
 	defer func() {
 		if err != nil {
@@ -304,7 +304,7 @@ func Start(ctx context.Context, container containerd.Container, isAttach bool, i
 	}
 
 	// If container has health checks configured, create and start systemd timer/service files.
-	if err := healthcheck.CreateTimer(ctx, container, cfg); err != nil {
+	if err := healthcheck.CreateTimer(ctx, container, cfg, nerdctlCmd, nerdctlArgs); err != nil {
 		return fmt.Errorf("failed to create healthcheck timer: %w", err)
 	}
 	if err := healthcheck.StartTimer(ctx, container, cfg); err != nil {
@@ -526,7 +526,7 @@ func Pause(ctx context.Context, client *containerd.Client, id string) error {
 }
 
 // Unpause unpauses a container by its id.
-func Unpause(ctx context.Context, client *containerd.Client, id string, cfg *config.Config) error {
+func Unpause(ctx context.Context, client *containerd.Client, id string, cfg *config.Config, nerdctlCmd string, nerdctlArgs []string) error {
 	container, err := client.LoadContainer(ctx, id)
 	if err != nil {
 		return err
@@ -543,7 +543,7 @@ func Unpause(ctx context.Context, client *containerd.Client, id string, cfg *con
 	}
 
 	// Recreate healthcheck related systemd timer/service files.
-	if err := healthcheck.CreateTimer(ctx, container, cfg); err != nil {
+	if err := healthcheck.CreateTimer(ctx, container, cfg, nerdctlCmd, nerdctlArgs); err != nil {
 		return fmt.Errorf("failed to create healthcheck timer: %w", err)
 	}
 	if err := healthcheck.StartTimer(ctx, container, cfg); err != nil {
