@@ -36,7 +36,7 @@ import (
 )
 
 // CreateTimer sets up the transient systemd timer and service for healthchecks.
-func CreateTimer(ctx context.Context, container containerd.Container, cfg *config.Config) error {
+func CreateTimer(ctx context.Context, container containerd.Container, cfg *config.Config, nerdctlCmd string, nerdctlArgs []string) error {
 	hc := extractHealthcheck(ctx, container)
 	if hc == nil {
 		return nil
@@ -48,24 +48,26 @@ func CreateTimer(ctx context.Context, container containerd.Container, cfg *confi
 	containerID := container.ID()
 	log.G(ctx).Debugf("Creating healthcheck timer unit: %s", containerID)
 
+	// Set all environment variables so that they are available for the nerdctl commands run via the systemd service file
 	cmdOpts := []string{}
 	if path := os.Getenv("PATH"); path != "" {
 		cmdOpts = append(cmdOpts, "--setenv=PATH="+path)
 	}
 
+	if nerdctlToml := os.Getenv("NERDCTL_TOML"); nerdctlToml != "" {
+		cmdOpts = append(cmdOpts, "--setenv=NERDCTL_TOML="+nerdctlToml)
+	}
+
+	if buildKitHost := os.Getenv("BUILDKIT_HOST"); buildKitHost != "" {
+		cmdOpts = append(cmdOpts, "--setenv=BUILDKIT_HOST="+buildKitHost)
+	}
+
 	// Always use health-interval for timer frequency
 	cmdOpts = append(cmdOpts, "--unit", containerID, "--on-unit-inactive="+hc.Interval.String(), "--timer-property=AccuracySec=1s")
 
-	// Get the full path to the current nerdctl binary
-	nerdctlPath, err := os.Executable()
-	if err != nil {
-		return fmt.Errorf("could not determine nerdctl executable path: %v", err)
-	}
-
-	cmdOpts = append(cmdOpts, nerdctlPath, "container", "healthcheck", containerID)
-	if log.G(ctx).Logger.IsLevelEnabled(log.DebugLevel) {
-		cmdOpts = append(cmdOpts, "--debug")
-	}
+	cmdOpts = append(cmdOpts, nerdctlCmd)
+	cmdOpts = append(cmdOpts, nerdctlArgs...)
+	cmdOpts = append(cmdOpts, "container", "healthcheck", containerID)
 
 	log.G(ctx).Debugf("creating healthcheck timer with: systemd-run %s", strings.Join(cmdOpts, " "))
 	run := exec.Command("systemd-run", cmdOpts...)
