@@ -302,36 +302,6 @@ func (s ServiceConfig) GetPullPolicy() (string, time.Duration, error) {
 	}
 }
 
-// BuildConfig is a type for build
-type BuildConfig struct {
-	Context            string                    `yaml:"context,omitempty" json:"context,omitempty"`
-	Dockerfile         string                    `yaml:"dockerfile,omitempty" json:"dockerfile,omitempty"`
-	DockerfileInline   string                    `yaml:"dockerfile_inline,omitempty" json:"dockerfile_inline,omitempty"`
-	Entitlements       []string                  `yaml:"entitlements,omitempty" json:"entitlements,omitempty"`
-	Args               MappingWithEquals         `yaml:"args,omitempty" json:"args,omitempty"`
-	Provenance         string                    `yaml:"provenance,omitempty" json:"provenance,omitempty"`
-	SBOM               string                    `yaml:"sbom,omitempty" json:"sbom,omitempty"`
-	SSH                SSHConfig                 `yaml:"ssh,omitempty" json:"ssh,omitempty"`
-	Labels             Labels                    `yaml:"labels,omitempty" json:"labels,omitempty"`
-	CacheFrom          StringList                `yaml:"cache_from,omitempty" json:"cache_from,omitempty"`
-	CacheTo            StringList                `yaml:"cache_to,omitempty" json:"cache_to,omitempty"`
-	NoCache            bool                      `yaml:"no_cache,omitempty" json:"no_cache,omitempty"`
-	AdditionalContexts Mapping                   `yaml:"additional_contexts,omitempty" json:"additional_contexts,omitempty"`
-	Pull               bool                      `yaml:"pull,omitempty" json:"pull,omitempty"`
-	ExtraHosts         HostsList                 `yaml:"extra_hosts,omitempty" json:"extra_hosts,omitempty"`
-	Isolation          string                    `yaml:"isolation,omitempty" json:"isolation,omitempty"`
-	Network            string                    `yaml:"network,omitempty" json:"network,omitempty"`
-	Target             string                    `yaml:"target,omitempty" json:"target,omitempty"`
-	Secrets            []ServiceSecretConfig     `yaml:"secrets,omitempty" json:"secrets,omitempty"`
-	ShmSize            UnitBytes                 `yaml:"shm_size,omitempty" json:"shm_size,omitempty"`
-	Tags               StringList                `yaml:"tags,omitempty" json:"tags,omitempty"`
-	Ulimits            map[string]*UlimitsConfig `yaml:"ulimits,omitempty" json:"ulimits,omitempty"`
-	Platforms          StringList                `yaml:"platforms,omitempty" json:"platforms,omitempty"`
-	Privileged         bool                      `yaml:"privileged,omitempty" json:"privileged,omitempty"`
-
-	Extensions Extensions `yaml:"#extensions,inline,omitempty" json:"-"`
-}
-
 // BlkioConfig define blkio config
 type BlkioConfig struct {
 	Weight          uint16           `yaml:"weight,omitempty" json:"weight,omitempty"`
@@ -594,12 +564,20 @@ const (
 type ServiceVolumeBind struct {
 	SELinux        string `yaml:"selinux,omitempty" json:"selinux,omitempty"`
 	Propagation    string `yaml:"propagation,omitempty" json:"propagation,omitempty"`
-	CreateHostPath bool   `yaml:"create_host_path,omitempty" json:"create_host_path,omitempty"`
+	CreateHostPath OptOut `yaml:"create_host_path,omitempty" json:"create_host_path,omitzero"`
 	Recursive      string `yaml:"recursive,omitempty" json:"recursive,omitempty"`
 
 	Extensions Extensions `yaml:"#extensions,inline,omitempty" json:"-"`
 }
 
+// OptOut is a boolean which default value is 'true'
+type OptOut bool
+
+func (o OptOut) IsZero() bool {
+	// Attribute can be omitted if value is true
+	return bool(o)
+}
+
 // SELinux represents the SELinux re-labeling options.
 const (
 	// SELinuxShared option indicates that the bind mount content is shared among multiple containers
